@@ -19,6 +19,7 @@
 
 #include <string.h>
 #include <stdint.h>
+#include <limits.h>
 
 //-------------------------------------------------------------------------------------------------------
 // Configure compilation options
@@ -37,11 +38,25 @@
 // Define __cdecl modifier
 #ifdef __GNUC__
     #ifndef __cdecl
-        #if defined(__i386__)
+        #if defined(__i386__) || defined(__i386)
             #define __cdecl __attribute__((__cdecl__))
-        #elif defined(__x86_64__)
+        #elif defined(__x86_64__) || defined(__x86_64) || defined(__amd64__) || defined(__amd64) || defined(_M_AMD64)
+            #define VST_64BIT_PLATFORM      1
             #define __cdecl
-        #elif defined(__arm__)
+        #elif defined(__aarch64__)
+            #define VST_64BIT_PLATFORM      1
+            #define __cdecl
+        #elif defined(__arm__) || defined(__arm) || defined(_M_ARM) || defined(_ARM)
+            #define __cdecl
+        #elif defined(__PPC64__) || defined(__ppc64__) || defined(__ppc64) || defined(__powerpc64__) || defined(_ARCH_PPC64)
+            #define VST_64BIT_PLATFORM      1
+            #define __cdecl
+        #elif defined(__PPC__) || defined(__ppc__) || defined(__powerpc__) || defined(__ppc) || defined(_M_PPC) || defined(_ARCH_PPC)
+            #define __cdecl
+        #elif defined(__s390x__) || defined(__s390__) || defined(__zarch__)
+            #define VST_64BIT_PLATFORM      1
+            #define __cdecl
+        #elif defined(__mips__) || defined(__mips) || defined(__MIPS__)
             #define __cdecl
         #endif /* __cdecl */
     #endif /* __cdecl */
@@ -53,13 +68,27 @@
     #define VST_C_EXTERN
 #endif /* __cplusplus */
 
-/** Test whether system runs in 64-bit moe */
-#ifndef VST_64BIT_PLATFORM
-    #define VST_64BIT_PLATFORM _WIN64 || __LP64__
-#endif /* VST_64BIT_PLATFORM */
+/** Test whether system runs in 64-bit mode */
+#ifdef __GNUC__
+    #ifndef VST_64BIT_PLATFORM
+        #if defined(__WORDSIZE) && (__WORDSIZE == 64)
+            #define VST_64BIT_PLATFORM      1
+        #elif defined(__SIZE_WIDTH__) && (__SIZE_WIDTH__ == 64)
+            #define VST_64BIT_PLATFORM      1
+        #endif /* __WORDSIZE, __SIZE_WIDTH__ */
+    #endif
+
+    #ifndef VST_64BIT_PLATFORM
+        #define VST_64BIT_PLATFORM  (__x86_64__) || (__aarch64__) || (__ppc64__) || (__s390x__) || (__zarch__)
+    #endif /* VST_64BIT_PLATFORM */
+#else
+    #ifndef VST_64BIT_PLATFORM
+        #define VST_64BIT_PLATFORM _WIN64 || __LP64__
+    #endif /* VST_64BIT_PLATFORM */
+#endif /* __GNUC__ */
 
 #if TARGET_API_MAC_CARBON
-    #ifdef __LP64__
+    #ifdef (__LP64__) || (__ppc64__)
         #pragma options align=power
     #else
         #pragma options align=mac68k
@@ -134,63 +163,94 @@ typedef int64_t VstInt64;
 #define chunkPresetMagic    CCONST('F', 'P', 'C', 'h')      /* Opaque chunk (preset) magic number for program chunk (FXP) */
 #define chunkBankMagic      CCONST('F', 'B', 'C', 'h')      /* Opaque chunk (preset) magic number for bank chunk (FXB) */
 
+/**
+ * Host can do the following
+ */
+#define canDoSendVstEvents                  "sendVstEvents"                     /* Host supports send of Vst events to plug-in */
+#define canDoSendVstMidiEvent               "sendVstMidiEvent"                  /* Host supports send of Vst events to plug-in */
+#define canDoSendVstTimeInfo                "sendVstTimeInfo"                   /* Host supports send of VstTimeInfo to plug-in */
+#define canDoReceiveVstEvents               "receiveVstEvents"                  /* Host can receive Vst events from plug-in */
+#define canDoReceiveVstMidiEvent            "receiveVstMidiEvent"               /* Host can receive MIDI events from plug-in */
+#define canDoReportConnectionChanges        "reportConnectionChanges"           /* Host will indicates the plug-in when something change in plug-in´s routing/connections with suspend/resume/setSpeakerArrangement */
+#define canDoAcceptIOChanges                "acceptIOChanges"                   /* Host supports ioChanged () */
+#define canDoSizeWindow                     "sizeWindow"                        /* used by VSTGUI */
+#define canDoOffline                        "offline"                           /* Host supports offline feature */
+#define canDoOpenFileSelector               "openFileSelector"                  /* Host supports function openFileSelector () */
+#define canDoCloseFileSelector              "closeFileSelector"                 /* Host supports function closeFileSelector () */
+#define canDoStartStopProcess               "startStopProcess"                  /* Host supports functions startProcess () and stopProcess () */
+#define canDoShellCategory                  "shellCategory"                     /* 'shell' handling via uniqueID. If supported by the Host and the Plug-in has the category kPlugCategShell */
+#define canDoSendVstMidiEventFlagIsRealtime "sendVstMidiEventFlagIsRealtime"    /* Host supports flags for VstMidiEvent */
+
+/**
+ * Plugin can do the following
+ */
+#define canDoSendVstEvents                  "sendVstEvents"                     /* plug-in will send Vst events to Host */
+#define canDoSendVstMidiEvent               "sendVstMidiEvent"                  /* plug-in will send MIDI events to Host */
+#define canDoReceiveVstEvents               "receiveVstEvents"                  /* plug-in can receive MIDI events from Host */
+#define canDoReceiveVstMidiEvent            "receiveVstMidiEvent"               /* plug-in can receive MIDI events from Host  */
+#define canDoReceiveVstTimeInfo             "receiveVstTimeInfo"                /* plug-in can receive Time info from Host  */
+#define canDoOffline                        "offline"                           /* plug-in supports offline functions (offlineNotify, offlinePrepare, offlineRun) */
+#define canDoMidiProgramNames               "midiProgramNames"                  /* plug-in supports function getMidiProgramName () */
+#define canDoBypass                         "bypass"                            /* plug-in supports function setBypass () */
+
+
 enum VstAEffectFlags
 {
     /** Plugin provides custom user interface/editor
      *
      */
-    effFlagsHasEditor           = 1 << 0,
+    effFlagsHasEditor           = 1 << 0, //!< effFlagsHasEditor
 
     /** This flag is deprecated
      * @deprecated since VST 2.4
      */
-    effFlagsHasClip             = 1 << 1,
+    effFlagsHasClip             = 1 << 1, //!< effFlagsHasClip
 
     /** This flag is deprecated
      * @deprecated since VST 2.4
      */
-    effFlagsHasVu               = 1 << 2,
+    effFlagsHasVu               = 1 << 2, //!< effFlagsHasVu
 
     /** This flag is deprecated
      * @deprecated since VST 2.4
      */
-    effFlagsCanMono             = 1 << 3,
+    effFlagsCanMono             = 1 << 3, //!< effFlagsCanMono
 
     /** Supports replacing process mode, default mode for VST 2.4
      *
      */
-    effFlagsCanReplacing        = 1 << 4,
+    effFlagsCanReplacing        = 1 << 4, //!< effFlagsCanReplacing
 
     /** Program data is handled in formatless chunks
      *
      */
-    effFlagsProgramChunks       = 1 << 5,
+    effFlagsProgramChunks       = 1 << 5, //!< effFlagsProgramChunks
 
     /** Plug-in is a synthesizer/instrument (VSTi),
      * host may assign mixer channels for its outputs
      *
      */
-    effFlagsIsSynth             = 1 << 8,
+    effFlagsIsSynth             = 1 << 8, //!< effFlagsIsSynth
 
     /** Plug-in does not produce sound when there is zero data on all inputs
      *
      */
-    effFlagsNoSoundInStop       = 1 << 9,
+    effFlagsNoSoundInStop       = 1 << 9, //!< effFlagsNoSoundInStop
 
     /** This flag is deprecated
      * @deprecated since VST 2.4
      */
-    effFlagsExtIsAsync          = 1 << 10,
+    effFlagsExtIsAsync          = 1 << 10,//!< effFlagsExtIsAsync
 
     /** This flag is deprecated
      * @deprecated since VST 2.4
      */
-    effFlagsExtHasBuffer        = 1 << 11,
+    effFlagsExtHasBuffer        = 1 << 11,//!< effFlagsExtHasBuffer
 
     /** Plug-in supports double precision processing
      * @since VST 2.4
      */
-    effFlagsCanDoubleReplacing  = 1 << 12
+    effFlagsCanDoubleReplacing  = 1 << 12 //!< effFlagsCanDoubleReplacing
 };
 
 /** Host to plugin communication codes
@@ -355,7 +415,7 @@ enum AEffectOpcodes
 
     /** Set program chunk
      * @param ptr pointer to chunk data
-     * @param value the size of byte
+     * @param value the size in bytes
      * @param index type of the chunk: 0 for bank, 1 for program
      */
     effSetChunk,
@@ -2441,7 +2501,7 @@ typedef struct fxProgram
 
     /** Type of chunk:
      *   fMagic ('FxCk') - regular chunk
-     *   chunkPresetMagic ('FPCh') - opaque chukn
+     *   chunkPresetMagic ('FPCh') - opaque chunk
      * @see fMagic
      * @see chunkPresetMagic
      */
