@@ -99,6 +99,7 @@ namespace lsp
 
         protected:
             static int process(jack_nframes_t nframes, void *arg);
+            static int sync_buffer_size(jack_nframes_t nframes, void *arg);
             static int jack_sync(jack_transport_state_t state, jack_position_t *pos, void *arg);
             static int latency_callback(jack_latency_callback_mode_t mode, void *arg);
             static void shutdown(void *arg);
@@ -120,6 +121,7 @@ namespace lsp
             status_t disconnect();
 
             void destroy();
+            void show_ui();
             bool transfer_dsp_to_ui();
 
             inline bool initialized() const     { return nState != S_CREATED;       }
@@ -190,6 +192,20 @@ namespace lsp
         return result;
     }
 
+    int JACKWrapper::sync_buffer_size(jack_nframes_t nframes, void *arg)
+    {
+        JACKWrapper *_this  = reinterpret_cast<JACKWrapper *>(arg);
+
+        for (size_t i=0, n=_this->vDataPorts.size(); i<n; ++i)
+        {
+            JACKDataPort *p = _this->vDataPorts.at(i);
+            if (p != NULL)
+                p->set_buffer_size(nframes);
+        }
+
+        return 0;
+    }
+
     int JACKWrapper::jack_sync(jack_transport_state_t state, jack_position_t *pos, void *arg)
     {
         dsp::context_t ctx;
@@ -365,6 +381,7 @@ namespace lsp
                 break;
 
             case R_CONTROL:
+            case R_BYPASS:
                 jp      = new JACKControlPort(port, this);
                 jup     = new JACKUIControlPort(jp);
                 break;
@@ -517,11 +534,24 @@ namespace lsp
         // Set-up shutdown handler
         jack_on_shutdown(pClient, shutdown, this);
 
+        // Determine size of buffer
+        size_t buf_size             = jack_get_buffer_size(pClient);
+        if (jack_set_buffer_size_callback(pClient, sync_buffer_size, this))
+        {
+            lsp_error("Could not setup buffer size callback");
+            nState = S_CONN_LOST;
+            return STATUS_DISCONNECTED;
+        }
+
         // Connect data ports
         for (size_t i=0, n=vDataPorts.size(); i<n; ++i)
         {
             JACKDataPort *dp = vDataPorts.at(i);
-            dp->connect();
+            if (dp != NULL)
+            {
+                dp->connect();
+                dp->set_buffer_size(buf_size);
+            }
         }
 
         // Set plugin sample rate and call for settings update
@@ -695,9 +725,6 @@ namespace lsp
     bool JACKWrapper::transfer_dsp_to_ui()
     {
         // Validate state
-        if (nState != S_CONNECTED)
-            return false;
-
         dsp::context_t ctx;
         dsp::start(&ctx);
 
@@ -900,6 +927,36 @@ namespace lsp
     {
         return sKVTMutex.unlock();
     }
+
+    void JACKWrapper::show_ui()
+    {
+        for (size_t i=0, n=vUIPorts.size(); i<n; ++i)
+        {
+            JACKUIPort *port = vUIPorts.at(i);
+            if (port != NULL)
+                port->notify_all();
+        }
+
+        size_request_t r;
+        LSPWindow *wnd      = pUI->root_window();
+        LSPDisplay *dpy     = wnd->display();
+
+        // Limit window size
+        wnd->size_request(&r);
+
+        // Set location and size of window
+        ssize_t w, h;
+        if (dpy->screen_size(wnd->screen(), &w, &h) == STATUS_OK)
+        {
+            w = (w - r.nMinWidth) >> 1;
+            h = (h - r.nMinHeight) >> 1;
+            wnd->set_geometry(w, h, r.nMinWidth, r.nMinHeight);
+        }
+        else
+            wnd->resize(r.nMinWidth, r.nMinHeight);
+
+        pUI->show();
+    }
 }
 
 #endif /* CONTAINER_JACK_WRAPPER_H_ */
