@@ -15,9 +15,12 @@
 #include <core/IWrapper.h>
 #include <core/ipc/NativeExecutor.h>
 #include <core/KVTDispatcher.h>
-#include <container/CairoCanvas.h>
 #include <container/lv2/lv2_sink.h>
 
+#ifndef LSP_NO_LV2_UI
+    #include <container/CairoCanvas.h>
+#endif
+
 namespace lsp
 {
     /** LV2 common plugin wrapper class
@@ -26,41 +29,44 @@ namespace lsp
     class LV2Wrapper: public IWrapper
     {
         private:
-            cvector<LV2Port>    vExtPorts;
-            cvector<LV2Port>    vAllPorts;      // List of all created ports, for garbage collection
-            cvector<LV2Port>    vPluginPorts;   // All plugin ports sorted in urid order
-            cvector<LV2Port>    vMeshPorts;
-            cvector<LV2Port>    vFrameBufferPorts;
-            cvector<LV2Port>    vMidiInPorts;
-            cvector<LV2Port>    vMidiOutPorts;
-            cvector<LV2Port>    vOscInPorts;
-            cvector<LV2Port>    vOscOutPorts;
-            cvector<port_t>     vGenMetadata;   // Generated metadata
+            cvector<LV2Port>        vExtPorts;
+            cvector<LV2Port>        vAllPorts;      // List of all created ports, for garbage collection
+            cvector<LV2Port>        vPluginPorts;   // All plugin ports sorted in urid order
+            cvector<LV2Port>        vMeshPorts;
+            cvector<LV2Port>        vFrameBufferPorts;
+            cvector<LV2Port>        vMidiInPorts;
+            cvector<LV2Port>        vMidiOutPorts;
+            cvector<LV2Port>        vOscInPorts;
+            cvector<LV2Port>        vOscOutPorts;
+            cvector<LV2AudioPort>   vAudioPorts;
+            cvector<port_t>         vGenMetadata;   // Generated metadata
 
-            plugin_t           *pPlugin;
-            LV2Extensions      *pExt;
-            ipc::IExecutor     *pExecutor;      // Executor service
-            void               *pAtomIn;        // Atom input port
-            void               *pAtomOut;       // Atom output port
-            float              *pLatency;       // Latency output port
-            size_t              nPatchReqs;     // Number of patch requests
-            size_t              nStateReqs;     // Number of state requests
-            ssize_t             nSyncTime;      // Synchronization time
-            ssize_t             nSyncSamples;   // Synchronization counter
-            ssize_t             nClients;       // Number of clients
-            ssize_t             nDirectClients; // Number of direct clients
-            bool                bQueueDraw;     // Queue draw request
-            bool                bUpdateSettings;// Settings update
-            float               fSampleRate;
-            uint8_t            *pOscPacket;     // OSC packet data
+            plugin_t               *pPlugin;
+            LV2Extensions          *pExt;
+            ipc::IExecutor         *pExecutor;      // Executor service
+            void                   *pAtomIn;        // Atom input port
+            void                   *pAtomOut;       // Atom output port
+            float                  *pLatency;       // Latency output port
+            size_t                  nPatchReqs;     // Number of patch requests
+            size_t                  nStateReqs;     // Number of state requests
+            ssize_t                 nSyncTime;      // Synchronization time
+            ssize_t                 nSyncSamples;   // Synchronization counter
+            ssize_t                 nClients;       // Number of clients
+            ssize_t                 nDirectClients; // Number of direct clients
+            bool                    bQueueDraw;     // Queue draw request
+            bool                    bUpdateSettings;// Settings update
+            float                   fSampleRate;
+            uint8_t                *pOscPacket;     // OSC packet data
 
-            position_t          sPosition;
-            KVTStorage          sKVT;
-            ipc::Mutex          sKVTMutex;
-            KVTDispatcher      *pKVTDispatcher;
+            position_t              sPosition;
+            KVTStorage              sKVT;
+            ipc::Mutex              sKVTMutex;
+            KVTDispatcher          *pKVTDispatcher;
 
-            CairoCanvas        *pCanvas;        // Canvas for drawing inline display
+#ifndef LSP_NO_LV2_UI
+            CairoCanvas            *pCanvas;        // Canvas for drawing inline display
             LV2_Inline_Display_Image_Surface sSurface; // Canvas surface
+#endif
 
         protected:
             LV2Port *create_port(const port_t *meta, const char *postfix);
@@ -95,7 +101,13 @@ namespace lsp
                 nSyncSamples    = 0;
                 nClients        = 0;
                 nDirectClients  = 0;
+#ifndef LSP_NO_LV2_UI
                 pCanvas         = NULL;
+                sSurface.data   = NULL;
+                sSurface.width  = 0;
+                sSurface.height = 0;
+                sSurface.stride = 0;
+#endif
                 bQueueDraw      = false;
                 bUpdateSettings = true;
                 fSampleRate     = DEFAULT_SAMPLE_RATE;
@@ -119,7 +131,13 @@ namespace lsp
                 nSyncSamples    = 0;
                 nClients        = 0;
                 nDirectClients  = 0;
+#ifndef LSP_NO_LV2_UI
                 pCanvas         = NULL;
+                sSurface.data   = NULL;
+                sSurface.width  = 0;
+                sSurface.height = 0;
+                sSurface.stride = 0;
+#endif
             }
 
         public:
@@ -177,7 +195,9 @@ namespace lsp
                 return &sPosition;
             }
 
+#ifndef LSP_NO_LV2_UI
             virtual ICanvas *create_canvas(ICanvas *&cv, size_t width, size_t height);
+#endif
 
             LV2Port *get_port(const char *id);
 
@@ -253,8 +273,12 @@ namespace lsp
                 break;
 
             case R_AUDIO:
-                result      = new LV2AudioPort(p, pExt);
+            {
+                LV2AudioPort *ap = new LV2AudioPort(p, pExt);
+                vAudioPorts.add(ap);
+                result          = ap;
                 break;
+            }
 
             case R_PORT_SET:
             {
@@ -304,6 +328,13 @@ namespace lsp
                     result      = new LV2InputPort(p, pExt);
                 break;
 
+            case R_BYPASS:
+                if (IS_OUT_PORT(p))
+                    result      = new LV2Port(p, pExt);
+                else
+                    result      = new LV2BypassPort(p, pExt);
+                break;
+
             default:
                 break;
         }
@@ -361,6 +392,14 @@ namespace lsp
                     lsp_trace("Added external port id=%s, external_id=%d", p->metadata()->id, int(vExtPorts.size() - 1));
                     break;
 
+                case R_BYPASS:
+                    p->set_id(pPlugin->ports_count());
+                    pPlugin->add_port(p);
+                    vPluginPorts.add(p);
+                    vExtPorts.add(p);
+                    lsp_trace("Added bypass port id=%s, external_id=%d", p->metadata()->id, int(vExtPorts.size() - 1));
+                    break;
+
                 default:
                     break;
             }
@@ -508,12 +547,12 @@ namespace lsp
             return;
 
         // Decode MIDI event
-        midi_event_t me;
+        midi::event_t me;
         const uint8_t *bytes        = reinterpret_cast<const uint8_t*>(ev + 1);
 
         // Debug
         #ifdef LSP_TRACE
-            #define TRACE_KEY(x)    case MIDI_MSG_ ## x: evt_type = #x; break;
+            #define TRACE_KEY(x)    case midi::MIDI_MSG_ ## x: evt_type = #x; break;
             lsp_trace("midi dump: %02x %02x %02x", int(bytes[0]), int(bytes[1]), int(bytes[2]));
 
             char tmp_evt_type[32];
@@ -551,7 +590,7 @@ namespace lsp
 
         #endif /* LSP_TRACE */
 
-        if (!decode_midi_message(&me, bytes))
+        if (midi::decode(&me, bytes) <= 0)
         {
             lsp_warn("Could not decode MIDI message");
             return;
@@ -804,11 +843,11 @@ namespace lsp
 
         for (size_t i=0; i<midi->nEvents; ++i)
         {
-            const midi_event_t *me = &midi->vEvents[i];
+            const midi::event_t *me = &midi->vEvents[i];
 
             // Debug
             #ifdef LSP_TRACE
-                #define TRACE_KEY(x)    case MIDI_MSG_ ## x: evt_type = #x; break;
+                #define TRACE_KEY(x)    case midi::MIDI_MSG_ ## x: evt_type = #x; break;
 
                 char tmp_evt_type[32];
                 const char *evt_type = NULL;
@@ -845,12 +884,13 @@ namespace lsp
 
             #endif /* LSP_TRACE */
 
-            buf.atom.size = encode_midi_message(me, buf.body);
-            if (!buf.atom.size)
+            ssize_t size = midi::encode(buf.body, me);
+            if (size <= 0)
             {
-                lsp_error("Tried to serialize invalid MIDI event");
+                lsp_error("Tried to serialize invalid MIDI event, error=%d", int(-size));
                 continue;
             }
+            buf.atom.size = size;
 
             lsp_trace("midi dump: %02x %02x %02x (%d: %d)",
                 int(buf.body[0]), int(buf.body[1]), int(buf.body[2]), int(buf.atom.size), int(buf.atom.size + sizeof(LV2_Atom)));
@@ -1216,12 +1256,6 @@ namespace lsp
 
     void LV2Wrapper::destroy()
     {
-        // Drop surface
-        sSurface.data           = NULL;
-        sSurface.width          = 0;
-        sSurface.height         = 0;
-        sSurface.stride         = 0;
-
         // Stop KVT dispatcher
         if (pKVTDispatcher != NULL)
         {
@@ -1231,6 +1265,13 @@ namespace lsp
             delete pKVTDispatcher;
         }
 
+#ifndef LSP_NO_LV2_UI
+        // Drop surface
+        sSurface.data           = NULL;
+        sSurface.width          = 0;
+        sSurface.height         = 0;
+        sSurface.stride         = 0;
+
         // Drop canvas
         lsp_trace("canvas = %p", pCanvas);
         if (pCanvas != NULL)
@@ -1239,6 +1280,7 @@ namespace lsp
             delete pCanvas;
             pCanvas     = NULL;
         }
+#endif
 
         // Shutdown and delete executor if exists
         if (pExecutor != NULL)
@@ -1349,7 +1391,7 @@ namespace lsp
             // Pre-process data in port
             if (port->pre_process(samples))
             {
-                lsp_trace("port changed: %s", port->metadata()->id);
+                lsp_trace("port changed: %s, value=%f", port->metadata()->id, port->getValue());
                 bUpdateSettings = true;
             }
         }
@@ -1362,8 +1404,20 @@ namespace lsp
             bUpdateSettings     = false;
         }
 
-        // Call the main processing unit
-        pPlugin->process(samples);
+        // Call the main processing unit (split data buffers into chunks not greater than MaxBlockLength)
+        size_t n_in_ports = vAudioPorts.size();
+        for (size_t off=0; off < samples; )
+        {
+            size_t to_process = samples - off;
+            if (to_process > pExt->nMaxBlockLength)
+                to_process = pExt->nMaxBlockLength;
+
+            for (size_t i=0; i<n_in_ports; ++i)
+                vAudioPorts.at(i)->sanitize(off, to_process);
+            pPlugin->process(to_process);
+
+            off += to_process;
+        }
 
         // Transmit atoms (if possible)
         transmit_atoms(samples);
@@ -1855,6 +1909,7 @@ namespace lsp
 
     inline LV2_Inline_Display_Image_Surface *LV2Wrapper::render_inline_display(size_t width, size_t height)
     {
+#ifndef LSP_NO_LV2_UI
         // Check for Inline display support
         const plugin_metadata_t *meta = pPlugin->get_metadata();
         if ((meta == NULL) || (!(meta->extensions & E_INLINE_DISPLAY)))
@@ -1893,8 +1948,12 @@ namespace lsp
 //            sSurface.data, int(sSurface.width), int(sSurface.height), int(sSurface.stride));
 
         return &sSurface;
+#else
+        return NULL;
+#endif
     }
 
+#ifndef LSP_NO_LV2_UI
     ICanvas *LV2Wrapper::create_canvas(ICanvas *&cv, size_t width, size_t height)
     {
         if ((cv != NULL) && (cv->width() == width) && (cv->height() == height))
@@ -1917,6 +1976,7 @@ namespace lsp
 
         return cv = ncv;
     }
+#endif
 
     KVTStorage *LV2Wrapper::kvt_lock()
     {
