@@ -12,6 +12,12 @@
 #include <container/vst/chunk.h>
 #include <core/ipc/NativeExecutor.h>
 
+#ifndef LSP_NO_VST_UI
+    #define IF_VST_UI_ON(...)       __VA_ARGS__
+#else
+    #define IF_VST_UI_ON(...)
+#endif
+
 namespace lsp
 {
     class VSTAudioPort;
@@ -19,25 +25,23 @@ namespace lsp
     class VSTPort;
     class VSTUIPort;
 
-    class VSTWrapper: public IWrapper, public IUIWrapper
+    class VSTWrapper: public IWrapper IF_VST_UI_ON(, public IUIWrapper)
     {
         private:
             plugin_t                   *pPlugin;
             AEffect                    *pEffect;
-            plugin_ui                  *pUI;
-            ERect                       sRect;
             audioMasterCallback         pMaster;
             ipc::IExecutor             *pExecutor;
             vst_chunk_t                 sChunk;
             bool                        bUpdateSettings;
             float                       fLatency;
+            VSTPort                    *pBypass;
 
             cvector<VSTAudioPort>       vInputs;        // List of input audio ports
             cvector<VSTAudioPort>       vOutputs;       // List of output audio ports
             cvector<VSTParameterPort>   vParams;        // List of controllable parameters
             cvector<VSTPort>            vPorts;         // List of all created VST ports
             cvector<VSTPort>            vProxyPorts;    // List of all created VST proxy ports
-            cvector<VSTUIPort>          vUIPorts;       // List of all created UI ports
             cvector<port_t>             vGenMetadata;   // Generated metadata
 
             position_t                  sPosition;
@@ -45,15 +49,26 @@ namespace lsp
             KVTStorage                  sKVT;
             ipc::Mutex                  sKVTMutex;
 
+            IF_VST_UI_ON(
+                plugin_ui                  *pUI;
+                ERect                       sRect;
+                cvector<VSTUIPort>          vUIPorts;       // List of all created UI ports
+            )
+
         private:
-            void transfer_dsp_to_ui();
+            IF_VST_UI_ON(
+                void transfer_dsp_to_ui();
+            )
 
             VSTPort *create_port(const port_t *port, const char *postfix);
             VSTPort *find_by_id(const char *id);
             void create_ports(const port_t *meta);
 
         protected:
-            static status_t slot_ui_resize(LSPWidget *sender, void *ptr, void *data);
+            IF_VST_UI_ON(
+                static status_t slot_ui_resize(LSPWidget *sender, void *ptr, void *data);
+            )
+
             status_t check_vst_header(const fxBank *bank, size_t size);
             void deserialize_v1(const fxBank *bank);
             void deserialize_v2_v3(const uint8_t *data, size_t bytes);
@@ -71,16 +86,22 @@ namespace lsp
             {
                 pPlugin         = plugin;
                 pEffect         = effect;
-                pUI             = NULL;
+
                 pMaster         = callback;
                 pExecutor       = NULL;
-                sRect.top       = 0;
-                sRect.left      = 0;
-                sRect.bottom    = 0;
-                sRect.right     = 0;
+
                 fLatency        = 0.0f;
+                pBypass         = NULL;
                 bUpdateSettings = true;
 
+                IF_VST_UI_ON(
+                    pUI             = NULL;
+                    sRect.top       = 0;
+                    sRect.left      = 0;
+                    sRect.bottom    = 0;
+                    sRect.right     = 0;
+                )
+
                 position_t::init(&sPosition);
             }
 
@@ -88,7 +109,10 @@ namespace lsp
             {
                 pPlugin         = NULL;
                 pEffect         = NULL;
-                pUI             = NULL;
+                IF_VST_UI_ON(
+                    pUI             = NULL;
+                )
+
                 pMaster         = NULL;
             }
 
@@ -105,10 +129,17 @@ namespace lsp
 
             inline void set_sample_rate(float sr)
             {
+                if (sr > MAX_SAMPLE_RATE)
+                {
+                    lsp_warn("Unsupported sample rate: %f, maximum supported sample rate is %ld", sr, long(MAX_SAMPLE_RATE));
+                    sr = MAX_SAMPLE_RATE;
+                }
                 pPlugin->set_sample_rate(sr);
                 bUpdateSettings = true;
             }
 
+            inline void set_block_size(size_t size);
+
             inline void mains_changed(VstIntPtr value)
             {
                 if (value)
@@ -117,12 +148,21 @@ namespace lsp
                     pPlugin->deactivate();
             }
 
+#ifndef LSP_NO_VST_UI
             bool show_ui(void *root_widget);
             void hide_ui();
             void iterate_ui();
             void destroy_ui();
             void resize_ui(const realize_t *r);
             ERect *get_ui_rect();
+#endif
+
+            inline bool has_bypass() const
+            {
+                return pBypass != NULL;
+            }
+
+            inline void set_bypass(bool bypass);
 
             virtual ipc::IExecutor *get_executor()
             {
@@ -174,25 +214,27 @@ namespace lsp
 
 // Here Port description should be included
 #include <container/vst/ports.h>
-#include <container/vst/ui_ports.h>
+#ifndef LSP_NO_VST_UI
+    #include <container/vst/ui_ports.h>
+#endif
 
 namespace lsp
 {
     VSTPort *VSTWrapper::create_port(const port_t *port, const char *postfix)
     {
         VSTPort *vp = NULL;
-        VSTUIPort *vup = NULL;
+        IF_VST_UI_ON(VSTUIPort *vup = NULL;)
 
         switch (port->role)
         {
             case R_MESH:
                 vp  = new VSTMeshPort(port, pEffect, pMaster);
-                vup = new VSTUIMeshPort(port, vp);
+                IF_VST_UI_ON(vup = new VSTUIMeshPort(port, vp);)
                 break;
 
             case R_FBUFFER:
                 vp  = new VSTFrameBufferPort(port, pEffect, pMaster);
-                vup = new VSTUIFrameBufferPort(port, vp);
+                IF_VST_UI_ON(vup = new VSTUIFrameBufferPort(port, vp);)
                 break;
 
             case R_MIDI:
@@ -207,15 +249,17 @@ namespace lsp
 
             case R_OSC:
                 vp      = new VSTOscPort(port, pEffect, pMaster);
-                if (IS_OUT_PORT(port))
-                    vup     = new VSTUIOscPortIn(port, vp);
-                else
-                    vup     = new VSTUIOscPortOut(port, vp);
+                IF_VST_UI_ON(
+                    if (IS_OUT_PORT(port))
+                        vup     = new VSTUIOscPortIn(port, vp);
+                    else
+                        vup     = new VSTUIOscPortOut(port, vp);
+                )
                 break;
 
             case R_PATH:
                 vp  = new VSTPathPort(port, pEffect, pMaster);
-                vup = new VSTUIPathPort(port, vp);
+                IF_VST_UI_ON(vup = new VSTUIPathPort(port, vp);)
                 break;
 
             case R_AUDIO:
@@ -224,17 +268,20 @@ namespace lsp
 
             case R_CONTROL:
             case R_METER:
+            case R_BYPASS:
                 // VST specifies only INPUT parameters, output should be read in different way
                 if (IS_OUT_PORT(port))
                 {
                     vp      = new VSTMeterPort(port, pEffect, pMaster);
-                    vup     = new VSTUIMeterPort(port, vp);
+                    IF_VST_UI_ON(vup     = new VSTUIMeterPort(port, vp);)
                 }
                 else
                 {
                     vp      = new VSTParameterPort(port, pEffect, pMaster);
-                    vup     = new VSTUIParameterPort(port, static_cast<VSTParameterPort *>(vp));
+                    IF_VST_UI_ON(vup     = new VSTUIParameterPort(port, static_cast<VSTParameterPort *>(vp));)
                 }
+                if (port->role == R_BYPASS)
+                    pBypass     = vp;
                 break;
 
             case R_PORT_SET:
@@ -243,8 +290,10 @@ namespace lsp
                 VSTPortGroup       *pg      = new VSTPortGroup(port, pEffect, pMaster);
                 pPlugin->add_port(pg);
 
-                VSTUIPortGroup     *upg     = new VSTUIPortGroup(pg);
-                vUIPorts.add(upg);
+                IF_VST_UI_ON(
+                    VSTUIPortGroup     *upg     = new VSTUIPortGroup(pg);
+                    vUIPorts.add(upg);
+                )
 
                 for (size_t row=0; row<pg->rows(); ++row)
                 {
@@ -281,8 +330,10 @@ namespace lsp
 
         if (vp != NULL)
             vPorts.add(vp);
-        if (vup != NULL)
-            vUIPorts.add(vup);
+        IF_VST_UI_ON(
+            if (vup != NULL)
+                vUIPorts.add(vup);
+        )
 
         return vp;
     }
@@ -316,6 +367,7 @@ namespace lsp
                     break;
 
                 case R_CONTROL:
+                case R_BYPASS:
                 case R_METER:
                     pPlugin->add_port(vp);
                     if (IS_IN_PORT(meta)) // VST specifies only INPUT parameters, output should be read in different way
@@ -337,6 +389,11 @@ namespace lsp
         lsp_trace("Binding ports");
         create_ports(m->ports);
 
+        // Get buffer size
+        ssize_t blk_size = pMaster(pEffect, audioMasterGetBlockSize, 0, 0, 0, 0);
+        if (blk_size > 0)
+            set_block_size(blk_size);
+
         // Update instance parameters
         e->numInputs                    = vInputs.size();
         e->numOutputs                   = vOutputs.size();
@@ -355,8 +412,10 @@ namespace lsp
 
     void VSTWrapper::destroy()
     {
+#ifndef LSP_NO_VST_UI
         // First destroy the UI
         destroy_ui();
+#endif
 
         // Shutdown and delete executor if exists
         if (pExecutor != NULL)
@@ -377,11 +436,14 @@ namespace lsp
         }
 
         // Destroy UI ports
-        for (size_t i=0; i<vUIPorts.size(); ++i)
-        {
-            lsp_trace("destroy ui port id=%s", vUIPorts[i]->metadata()->id);
-            delete vUIPorts[i];
-        }
+#ifndef LSP_NO_VST_UI
+            for (size_t i=0; i<vUIPorts.size(); ++i)
+            {
+                lsp_trace("destroy ui port id=%s", vUIPorts[i]->metadata()->id);
+                delete vUIPorts[i];
+            }
+            vUIPorts.clear();
+#endif
 
         // Destroy ports
         for (size_t i=0; i<vPorts.size(); ++i)
@@ -389,6 +451,7 @@ namespace lsp
             lsp_trace("destroy port id=%s", vPorts[i]->metadata()->id);
             delete vPorts[i];
         }
+        vPorts.clear();
 
         // Cleanup generated metadata
         for (size_t i=0; i<vGenMetadata.size(); ++i)
@@ -401,8 +464,6 @@ namespace lsp
         vInputs.clear();
         vOutputs.clear();
         vParams.clear();
-        vPorts.clear();
-        vUIPorts.clear();
 
         pMaster     = NULL;
         pEffect     = NULL;
@@ -410,6 +471,19 @@ namespace lsp
         lsp_trace("destroy complete");
     }
 
+    void VSTWrapper::set_block_size(size_t size)
+    {
+        lsp_trace("Block size for audio processing: %d", int(size));
+
+        // Sync buffer size to all input ports
+        for (size_t i=0, n=vInputs.size(); i<n; ++i)
+        {
+            VSTAudioPort *p = vInputs.at(i);
+            if (p != NULL)
+                p->set_blk_size(size);
+        }
+    }
+
     void VSTWrapper::sync_position()
     {
         VstTimeInfo *info   = FromVstPtr<VstTimeInfo>(pMaster(pEffect, audioMasterGetTime, 0, kVstPpqPosValid | kVstTempoValid | kVstBarsValid | kVstCyclePosValid | kVstTimeSigValid, NULL, 0.0f));
@@ -467,6 +541,7 @@ namespace lsp
             return;
         }
 
+#ifndef LSP_NO_VST_UI
         // Sync UI state
         if (pUI != NULL)
         {
@@ -475,6 +550,7 @@ namespace lsp
         }
         else if (pPlugin->ui_active())
             pPlugin->deactivate_ui();
+#endif
 
         // Synchronize position
         sync_position();
@@ -485,14 +561,14 @@ namespace lsp
         {
             VSTAudioPort *p = vInputs.at(i);
             if (p != NULL)
-                p->bind(inputs[i]);
+                p->bind(inputs[i], samples);
         }
         size_t n_outputs = vOutputs.size();
         for (size_t i=0; i < n_outputs; ++i)
         {
             VSTAudioPort *p = vOutputs.at(i);
             if (p != NULL)
-                p->bind(outputs[i]);
+                p->bind(outputs[i], samples);
         }
 
         // Process ALL ports for changes
@@ -571,6 +647,7 @@ namespace lsp
         run(inputs, outputs, samples);
     }
 
+#ifndef LSP_NO_VST_UI
     bool VSTWrapper::show_ui(void *root_widget)
     {
         lsp_trace("show ui");
@@ -591,7 +668,7 @@ namespace lsp
             // Add pre-generated ports
             for (size_t i=0; i<vUIPorts.size(); ++i)
             {
-                VSTUIPort  *vp      = vUIPorts[i];
+                VSTUIPort  *vp      = vUIPorts.at(i);
                 lsp_trace("Adding UI port id=%s", vp->metadata()->id);
                 vp->resync();
                 pUI->add_port(vp);
@@ -608,8 +685,22 @@ namespace lsp
                 wnd->slots()->bind(LSPSLOT_RESIZE, slot_ui_resize, this);
         }
 
-        pUI->show();
+        // Force all parameters to be re-shipped to the UI
+        for (size_t i=0; i<vUIPorts.size(); ++i)
+        {
+            VSTUIPort  *vp      = vUIPorts.at(i);
+            if (vp != NULL)
+                vp->notify_all();
+        }
 
+        if (sKVTMutex.lock())
+        {
+            sKVT.touch_all(KVT_TO_UI);
+            sKVTMutex.unlock();
+        }
+        transfer_dsp_to_ui();
+
+        // Show the UI window
         LSPWindow *wnd  = pUI->root_window();
         size_request_t sr;
         wnd->size_request(&sr);
@@ -626,24 +717,7 @@ namespace lsp
         r.nHeight       = sr.nMinHeight;
         resize_ui(&r);
 
-        // Force all parameters to be re-shipped to the UI
-        if (sKVTMutex.lock())
-        {
-            sKVT.touch_all(KVT_TO_UI);
-            sKVTMutex.unlock();
-        }
-//
-//        wnd->set_width(sr.nMinWidth);
-//        wnd->set_height(sr.nMinHeight);
-
-//        // Show window
-//        lsp_trace("create widget hierarchy pWidget=%p", pWidget);
-//        gtk_widget_show_all(pWidget);
-//        gdk_display_sync(gdk_display_get_default());
-
-
-        // Transfer state
-        transfer_dsp_to_ui();
+        pUI->show();
 
         return true;
     }
@@ -733,35 +807,6 @@ namespace lsp
         if (pUI == NULL)
             return;
 
-//        LSPWindow *wnd  = pUI->root_window();
-//        if ((wnd != NULL) && (wnd->size_request_pending()))
-//        {
-//            size_request_t sr;
-//            wnd->size_request(&sr);
-//            sRect.top       = 0;
-//            sRect.left      = 0;
-//            sRect.right     = sr.nMinWidth;
-//            sRect.bottom    = sr.nMinHeight;
-//            lsp_trace("Window request width=%d, height=%d", int(sr.nMinWidth), int(sr.nMinHeight));
-//            pMaster(pEffect, audioMasterSizeWindow, sr.nMinWidth, sr.nMinHeight, 0, 0);
-//
-//            wnd->query_draw();
-//            realize_t r;
-//            r.nLeft         = 0;
-//            r.nTop          = 0;
-//            r.nWidth        = sr.nMinWidth;
-//            r.nHeight       = sr.nMinHeight;
-//            wnd->set_geometry(&r);
-//
-////            sr.nMaxWidth    = sr.nMinWidth;
-////            sr.nMaxHeight   = sr.nMinHeight;
-////
-////            wnd->set_size_constraints(&sr);
-//            wnd->realize(&r);
-////            wnd->query_draw();
-////            wnd->set_geometry(&r);
-//        }
-
         // Try to sync position
         pUI->position_updated(&sPosition);
         pUI->sync_meta_ports();
@@ -835,6 +880,8 @@ namespace lsp
         }
     }
 
+#endif
+
     #ifdef LSP_TRACE
         static void dump_vst_bank(const void *bank, size_t ck_size)
         {
@@ -1475,6 +1522,11 @@ namespace lsp
         }
     }
 
+    void VSTWrapper::set_bypass(bool bypass)
+    {
+        pBypass->writeValue((bypass) ? 1.0f : 0.0f);
+    }
+
     ICanvas *VSTWrapper::create_canvas(ICanvas *&cv, size_t width, size_t height)
     {
         return NULL;
