@@ -32,6 +32,8 @@
 #include <plugins/mb_compressor.h>
 #include <plugins/profiler.h>
 #include <plugins/room_builder.h>
+#include <plugins/mb_expander.h>
+#include <plugins/mb_gate.h>
 
 #include <plugins/nonlinear_convolver.h>
 
