@@ -12,6 +12,7 @@
 
 #define BUF_GRANULARITY         8192
 #define GAIN_LOWERING           0.891250938134 /* 0.944060876286 */
+#define MIN_LIMITER_RELEASE     5.0f
 
 namespace lsp
 {
@@ -282,12 +283,12 @@ namespace lsp
 //        #endif /* LSP_DEBUG */
     }
 
-    void Limiter::init_comp(comp_t *comp, float time)
+    void Limiter::init_comp(comp_t *comp)
     {
         comp->fKS           = fThreshold * fKnee;
         comp->fKE           = fThreshold / fKnee;
-        comp->fTauAttack    = 1.0f - expf(M_SQRT2 / (millis_to_samples(nSampleRate, fAttack)));
-        comp->fTauRelease   = 1.0f - expf(logf(1.0f - M_SQRT1_2) / (millis_to_samples(nSampleRate, time * fRelease)));
+        comp->fTauAttack    = 1.0f - expf(logf(1.0f - M_SQRT1_2) / (millis_to_samples(nSampleRate, fAttack)));
+        comp->fTauRelease   = 1.0f - expf(logf(1.0f - M_SQRT1_2) / (millis_to_samples(nSampleRate, fRelease + MIN_LIMITER_RELEASE)));
         comp->fAmp          = 1.0f / nLookahead;
         lsp_trace("attack=%f, release=%f, tau_attack=%f, tau_release=%f", fAttack, fRelease, comp->fTauAttack, comp->fTauRelease);
 
@@ -370,7 +371,7 @@ namespace lsp
         switch (nMode)
         {
             case LM_COMPRESSOR:
-                init_comp(&sComp, 20.0f);
+                init_comp(&sComp);
                 break;
 
             case LM_HERM_THIN:
@@ -395,17 +396,17 @@ namespace lsp
                 break;
 
             case LM_MIXED_HERM:
-                init_comp(&sMixed.sComp, 20.0f);
+                init_comp(&sMixed.sComp);
                 init_sat(&sMixed.sSat);
                 break;
 
             case LM_MIXED_EXP:
-                init_comp(&sMixed.sComp, 20.0f);
+                init_comp(&sMixed.sComp);
                 init_exp(&sMixed.sExp);
                 break;
 
             case LM_MIXED_LINE:
-                init_comp(&sMixed.sComp, 20.0f);
+                init_comp(&sMixed.sComp);
                 init_line(&sMixed.sLine);
                 break;
 
@@ -421,7 +422,7 @@ namespace lsp
     {
         if (comp->fEnvelope < comp->fKS)
             return 1.0f;
-        else if (comp->fEnvelope > comp->fKE)
+        else if (comp->fEnvelope >= comp->fKE)
             return fThreshold / comp->fEnvelope;
 
         float lx    = logf(comp->fEnvelope);
@@ -565,7 +566,6 @@ namespace lsp
 
             // Get delayed sample
             float ds    = sDelay.process(src[i]);
-            float ads   = (ds < 0.0f) ? -ds : ds;
 
             // Check that limiter has triggered (overwrite sidechain signal)
             if (sComp.nCountdown > 0)
@@ -594,13 +594,6 @@ namespace lsp
                                     sComp.fTauRelease * (ls - sComp.fEnvelope);
             float r             = reduction(&sComp);
 
-            // Prevent from overloading and store processed sample
-            if ((r*ads) >= fThreshold)
-            {
-                sComp.fEnvelope     = sComp.fKE; // Force env to be of specified size
-                r                   = fThreshold / ads;
-            }
-
             gain[i]             = r;
             dst[i]              = r*ds;
         }
@@ -750,8 +743,8 @@ namespace lsp
                 }
                 else if (ls >= fThreshold)
                 {
-                    comp->fSample         = ls;
-                    comp->nCountdown      = nLookahead;
+                    comp->fSample       = ls;
+                    comp->nCountdown    = nLookahead;
                 }
 
                 // Calculate envelope and reduction
@@ -854,6 +847,11 @@ namespace lsp
 
     void Limiter::process(float *dst, float *gain, const float *src, const float *sc, size_t samples)
     {
+        // Force settings update if there are any
+        if (nUpdate)
+            update_settings();
+
+        // Perform processing
         switch (nMode)
         {
             case LM_COMPRESSOR:
