@@ -20,6 +20,7 @@
 #include <dsp/arch/x86/avx/const.h>
 
 #include <dsp/arch/x86/avx/copy.h>
+#include <dsp/arch/x86/avx/float.h>
 #include <dsp/arch/x86/avx/complex.h>
 #include <dsp/arch/x86/avx/pcomplex.h>
 
@@ -42,6 +43,11 @@
 #include <dsp/arch/x86/avx/filters/static.h>
 #include <dsp/arch/x86/avx/filters/dynamic.h>
 #include <dsp/arch/x86/avx/filters/transform.h>
+#include <dsp/arch/x86/avx/filters/transfer.h>
+
+#include <dsp/arch/x86/avx/msmatrix.h>
+#include <dsp/arch/x86/avx/resampling.h>
+#include <dsp/arch/x86/avx/convolution.h>
 
 #undef DSP_ARCH_X86_AVX_IMPL
 
@@ -90,18 +96,21 @@ namespace avx
 
         lsp_trace("Optimizing DSP for AVX instruction set");
 
-        EXPORT2_X64(biquad_process_x8, x64_biquad_process_x8);
-        EXPORT2_X64(dyn_biquad_process_x8, x64_dyn_biquad_process_x8);
-
         TEST_EXPORT(avx::copy);
 
         // This routine sucks on AMD Bulldozer processor family but is pretty great on Intel
         // Not tested on AMD Processors above Bulldozer family
         bool favx   = feature_check(f, FEAT_FAST_AVX);
+        bool ffma   = favx && feature_check(f, FEAT_FAST_FMA3);
 
         CEXPORT2_X64(favx, reverse1, reverse1);
         CEXPORT2_X64(favx, reverse2, reverse2);
 
+        CEXPORT1(favx, limit1);
+        CEXPORT1(favx, limit2);
+        CEXPORT1(favx, sanitize1);
+        CEXPORT1(favx, sanitize2);
+
         // Conditional export, depending on fast AVX implementation
         CEXPORT1(favx, add_k2);
         CEXPORT1(favx, sub_k2);
@@ -109,6 +118,8 @@ namespace avx
         CEXPORT1(favx, mul_k2);
         CEXPORT1(favx, div_k2);
         CEXPORT1(favx, rdiv_k2);
+        CEXPORT1(favx, mod_k2);
+        CEXPORT1(favx, rmod_k2);
 
         CEXPORT1(favx, add_k3);
         CEXPORT1(favx, sub_k3);
@@ -116,6 +127,8 @@ namespace avx
         CEXPORT1(favx, mul_k3);
         CEXPORT1(favx, div_k3);
         CEXPORT1(favx, rdiv_k3);
+        CEXPORT1(favx, mod_k3);
+        CEXPORT1(favx, rmod_k3);
 
         CEXPORT1(favx, add2);
         CEXPORT1(favx, sub2);
@@ -123,11 +136,14 @@ namespace avx
         CEXPORT1(favx, mul2);
         CEXPORT1(favx, div2);
         CEXPORT1(favx, rdiv2);
+        CEXPORT1(favx, mod2);
+        CEXPORT1(favx, rmod2);
 
         CEXPORT1(favx, add3);
         CEXPORT1(favx, sub3);
         CEXPORT1(favx, mul3);
         CEXPORT1(favx, div3);
+        CEXPORT1(favx, mod3);
 
         CEXPORT1(favx, fmadd_k3);
         CEXPORT1(favx, fmsub_k3);
@@ -135,6 +151,8 @@ namespace avx
         CEXPORT1(favx, fmmul_k3);
         CEXPORT1(favx, fmdiv_k3);
         CEXPORT1(favx, fmrdiv_k3);
+        CEXPORT1(favx, fmmod_k3);
+        CEXPORT1(favx, fmrmod_k3);
 
         CEXPORT1(favx, fmadd_k4);
         CEXPORT1(favx, fmsub_k4);
@@ -142,6 +160,8 @@ namespace avx
         CEXPORT1(favx, fmmul_k4);
         CEXPORT1(favx, fmdiv_k4);
         CEXPORT1(favx, fmrdiv_k4);
+        CEXPORT1(favx, fmmod_k4);
+        CEXPORT1(favx, fmrmod_k4);
 
         CEXPORT1(favx, fmadd3);
         CEXPORT1(favx, fmsub3);
@@ -149,6 +169,8 @@ namespace avx
         CEXPORT1(favx, fmmul3);
         CEXPORT1(favx, fmdiv3);
         CEXPORT1(favx, fmrdiv3);
+        CEXPORT1(favx, fmmod3);
+        CEXPORT1(favx, fmrmod3);
 
         CEXPORT1(favx, fmadd4);
         CEXPORT1(favx, fmsub4);
@@ -156,6 +178,8 @@ namespace avx
         CEXPORT1(favx, fmmul4);
         CEXPORT1(favx, fmdiv4);
         CEXPORT1(favx, fmrdiv4);
+        CEXPORT1(favx, fmmod4);
+        CEXPORT1(favx, fmrmod4);
 
         CEXPORT2_X64(favx, abs_add2, x64_abs_add2);
         CEXPORT2_X64(favx, abs_sub2, x64_abs_sub2);
@@ -192,6 +216,19 @@ namespace avx
         CEXPORT1(favx, pcomplex_rcp1);
         CEXPORT1(favx, pcomplex_rcp2);
 
+        CEXPORT1(favx, biquad_process_x1);
+        CEXPORT1(favx, biquad_process_x2);
+        CEXPORT1(favx, biquad_process_x4);
+        EXPORT2_X64(biquad_process_x8, x64_biquad_process_x8);
+
+        CEXPORT1(favx, dyn_biquad_process_x1);
+        CEXPORT1(favx, dyn_biquad_process_x2);
+        CEXPORT1(favx, dyn_biquad_process_x4);
+        EXPORT2_X64(dyn_biquad_process_x8, x64_dyn_biquad_process_x8);
+
+        CEXPORT1(favx, bilinear_transform_x1);
+        CEXPORT1(favx, bilinear_transform_x2);
+        CEXPORT1(favx, bilinear_transform_x4);
         CEXPORT2_X64(favx, bilinear_transform_x8, x64_bilinear_transform_x8);
 
         CEXPORT1(favx, h_sum);
@@ -219,6 +256,13 @@ namespace avx
         CEXPORT1(favx, abs_max);
         CEXPORT1(favx, abs_minmax);
 
+        CEXPORT1(favx, lr_to_ms);
+        CEXPORT1(favx, lr_to_mid);
+        CEXPORT1(favx, lr_to_side);
+        CEXPORT1(favx, ms_to_lr);
+        CEXPORT1(favx, ms_to_left);
+        CEXPORT1(favx, ms_to_right);
+
         CEXPORT1(favx, direct_fft);
         CEXPORT1(favx, reverse_fft);
         CEXPORT1(favx, normalize_fft2);
@@ -232,27 +276,70 @@ namespace avx
         CEXPORT1(favx, fastconv_apply);
         CEXPORT1(favx, fastconv_parse_apply);
 
+        CEXPORT1(favx, filter_transfer_calc_ri);
+        CEXPORT1(favx, filter_transfer_apply_ri);
+        CEXPORT1(favx, filter_transfer_calc_pc);
+        CEXPORT1(favx, filter_transfer_apply_pc);
+
+        CEXPORT1(favx, lanczos_resample_2x2);
+        CEXPORT1(favx, lanczos_resample_2x3);
+        CEXPORT1(favx, lanczos_resample_3x2);
+        CEXPORT1(favx, lanczos_resample_3x3);
+        CEXPORT1(favx, lanczos_resample_4x2);
+        CEXPORT1(favx, lanczos_resample_4x3);
+        CEXPORT1(favx, lanczos_resample_6x2);
+        CEXPORT1(favx, lanczos_resample_6x3);
+        CEXPORT1(favx, lanczos_resample_8x2);
+        CEXPORT1(favx, lanczos_resample_8x3);
+
+        CEXPORT1(favx, downsample_2x);
+        CEXPORT1(favx, downsample_3x);
+        CEXPORT1(favx, downsample_4x);
+        CEXPORT1(favx, downsample_6x);
+        CEXPORT1(favx, downsample_8x);
+
+        CEXPORT1(favx, convolve);
+
         // FMA3 support?
         if (f->features & CPU_OPTION_FMA3)
         {
             lsp_trace("Optimizing DSP for FMA3 instruction set");
 
             // Conditional export, depending on fast AVX implementation
-            CEXPORT2_X64(favx, fmadd_k3, fmadd_k3_fma3);
-            CEXPORT2_X64(favx, fmsub_k3, fmsub_k3_fma3);
-            CEXPORT2_X64(favx, fmrsub_k3, fmrsub_k3_fma3);
+            CEXPORT2(favx, mod2, mod2_fma3);
+            CEXPORT2(favx, rmod2, rmod2_fma3);
 
-            CEXPORT2_X64(favx, fmadd_k4, fmadd_k4_fma3);
-            CEXPORT2_X64(favx, fmsub_k4, fmsub_k4_fma3);
-            CEXPORT2_X64(favx, fmrsub_k4, fmrsub_k4_fma3);
+            CEXPORT2(favx, mod3, mod3_fma3);
 
-            CEXPORT2_X64(favx, fmadd3, fmadd3_fma3);
-            CEXPORT2_X64(favx, fmsub3, fmsub3_fma3);
-            CEXPORT2_X64(favx, fmrsub3, fmrsub3_fma3);
+            CEXPORT2(favx, mod_k2, mod_k2_fma3);
+            CEXPORT2(favx, rmod_k2, rmod_k2_fma3);
 
-            CEXPORT2_X64(favx, fmadd4, fmadd4_fma3);
-            CEXPORT2_X64(favx, fmsub4, fmsub4_fma3);
-            CEXPORT2_X64(favx, fmrsub4, fmrsub4_fma3);
+            CEXPORT2(favx, mod_k3, mod_k3_fma3);
+            CEXPORT2(favx, rmod_k3, rmod_k3_fma3);
+
+            CEXPORT2(favx, fmadd_k3, fmadd_k3_fma3);
+            CEXPORT2(favx, fmsub_k3, fmsub_k3_fma3);
+            CEXPORT2(favx, fmrsub_k3, fmrsub_k3_fma3);
+            CEXPORT2(favx, fmmod_k3, fmmod_k3_fma3);
+            CEXPORT2(favx, fmrmod_k3, fmrmod_k3_fma3);
+
+            CEXPORT2(favx, fmadd_k4, fmadd_k4_fma3);
+            CEXPORT2(favx, fmsub_k4, fmsub_k4_fma3);
+            CEXPORT2(favx, fmrsub_k4, fmrsub_k4_fma3);
+            CEXPORT2(favx, fmmod_k4, fmmod_k4_fma3);
+            CEXPORT2(favx, fmrmod_k4, fmrmod_k4_fma3);
+
+            CEXPORT2(favx, fmadd3, fmadd3_fma3);
+            CEXPORT2(favx, fmsub3, fmsub3_fma3);
+            CEXPORT2(favx, fmrsub3, fmrsub3_fma3);
+            CEXPORT2(favx, fmmod3, fmmod3_fma3);
+            CEXPORT2(favx, fmrmod3, fmrmod3_fma3);
+
+            CEXPORT2(favx, fmadd4, fmadd4_fma3);
+            CEXPORT2(favx, fmsub4, fmsub4_fma3);
+            CEXPORT2(favx, fmrsub4, fmrsub4_fma3);
+            CEXPORT2(favx, fmmod4, fmmod4_fma3);
+            CEXPORT2(favx, fmrmod4, fmrmod4_fma3);
 
             CEXPORT2(favx, complex_mul2, complex_mul2_fma3);
             CEXPORT2(favx, complex_mul3, complex_mul3_fma3);
@@ -282,9 +369,23 @@ namespace avx
             CEXPORT2(favx, fastconv_apply, fastconv_apply_fma3);
             CEXPORT2(favx, fastconv_parse_apply, fastconv_parse_apply_fma3);
 
-            // Non-conditional export
-            EXPORT2(biquad_process_x8, biquad_process_x8_fma3);
-            EXPORT2_X64(dyn_biquad_process_x8, dyn_biquad_process_x8_fma3);
+            CEXPORT2(favx, filter_transfer_calc_ri, filter_transfer_calc_ri_fma3);
+            CEXPORT2(favx, filter_transfer_apply_ri, filter_transfer_apply_ri_fma3);
+            CEXPORT2(favx, filter_transfer_calc_pc, filter_transfer_calc_pc_fma3);
+            CEXPORT2(favx, filter_transfer_apply_pc, filter_transfer_apply_pc_fma3);
+
+            CEXPORT2(favx, convolve, convolve_fma3);
+
+
+            CEXPORT2(favx, biquad_process_x1, biquad_process_x1_fma3);
+            CEXPORT2(favx, biquad_process_x2, biquad_process_x2_fma3);
+            CEXPORT2(favx, biquad_process_x4, biquad_process_x4_fma3);
+            CEXPORT2(ffma, biquad_process_x8, biquad_process_x8_fma3);
+
+            CEXPORT2(ffma, dyn_biquad_process_x1, dyn_biquad_process_x1_fma3);
+            CEXPORT2(favx, dyn_biquad_process_x2, dyn_biquad_process_x2_fma3);
+            CEXPORT2(favx, dyn_biquad_process_x4, dyn_biquad_process_x4_fma3);
+            CEXPORT2(ffma, dyn_biquad_process_x8, dyn_biquad_process_x8_fma3);
         }
     }
 
