@@ -50,6 +50,7 @@ namespace sse // TODO: make constants common for all architectures
 
 #include <dsp/arch/x86/sse/mxcsr.h>
 #include <dsp/arch/x86/sse/copy.h>
+#include <dsp/arch/x86/sse/float.h>
 
 #include <dsp/arch/x86/sse/pmath/op_kx.h>
 #include <dsp/arch/x86/sse/pmath/op_vv.h>
@@ -80,6 +81,7 @@ namespace sse // TODO: make constants common for all architectures
 #include <dsp/arch/x86/sse/filters/static.h>
 #include <dsp/arch/x86/sse/filters/dynamic.h>
 #include <dsp/arch/x86/sse/filters/transform.h>
+#include <dsp/arch/x86/sse/filters/transfer.h>
 
 #include <dsp/arch/x86/sse/3dmath.h>
 
@@ -145,6 +147,8 @@ namespace sse
         EXPORT1(fill_one);
         EXPORT1(fill_zero);
         EXPORT1(fill_minus_one);
+        EXPORT1(limit1);
+        EXPORT1(limit2);
 
         EXPORT1(ipowf);
         EXPORT1(irootf);
@@ -301,14 +305,16 @@ namespace sse
         EXPORT1(dyn_biquad_process_x4);
         EXPORT1(dyn_biquad_process_x8);
 
+        EXPORT1(filter_transfer_calc_ri);
+        EXPORT1(filter_transfer_apply_ri);
+        EXPORT1(filter_transfer_calc_pc);
+        EXPORT1(filter_transfer_apply_pc);
+
         EXPORT1(bilinear_transform_x1);
         EXPORT1(bilinear_transform_x2);
         EXPORT1(bilinear_transform_x4);
         EXPORT1(bilinear_transform_x8);
 
-        EXPORT1(axis_apply_log1);
-        EXPORT1(axis_apply_log2);
-        EXPORT1(rgba32_to_bgra32);
         EXPORT1(fill_rgba);
         EXPORT1(fill_hsla);
 
