@@ -522,17 +522,9 @@ namespace x86
         EXPORT1(info);
 
         EXPORT1(copy);
-        EXPORT1(copy_saturated);
-        EXPORT1(saturate);
         EXPORT1(rgba32_to_bgra32);
         EXPORT1(abgr32_to_bgra32);
 
-        if (f.features & CPU_OPTION_CMOV)
-        {
-            EXPORT2(copy_saturated, copy_saturated_cmov);
-            EXPORT2(saturate, saturate_cmov);
-        }
-
         // Initialize extensions
         sse::dsp_init(&f);
         sse2::dsp_init(&f);
