@@ -78,6 +78,10 @@ namespace lsp
 
             if (!c->sSC.init(channels, gate_base_metadata::REACTIVITY_MAX))
                 return;
+            if (!c->sSCEq.init(2, 12))
+                return;
+            c->sSCEq.set_mode(EQM_IIR);
+            c->sSC.set_pre_equalizer(&c->sSCEq);
 
             c->vIn              = reinterpret_cast<float *>(ptr);
             ptr                += buf_size;
@@ -115,6 +119,10 @@ namespace lsp
             c->pScSource        = NULL;
             c->pScReactivity    = NULL;
             c->pScPreamp        = NULL;
+            c->pScHpfMode       = NULL;
+            c->pScHpfFreq       = NULL;
+            c->pScLpfMode       = NULL;
+            c->pScLpfFreq       = NULL;
 
             c->pHyst            = NULL;
             c->pThresh[0]       = NULL;
@@ -194,7 +202,6 @@ namespace lsp
             if ((i > 0) && (nMode == GM_STEREO))
             {
                 channel_t *sc       = &vChannels[0];
-                c->pSC              = sc->pSC;
                 c->pScType          = sc->pScType;
                 c->pScSource        = sc->pScSource;
                 c->pScMode          = sc->pScMode;
@@ -202,6 +209,10 @@ namespace lsp
                 c->pScListen        = sc->pScListen;
                 c->pScReactivity    = sc->pScReactivity;
                 c->pScPreamp        = sc->pScPreamp;
+                c->pScHpfMode       = sc->pScHpfMode;
+                c->pScHpfFreq       = sc->pScHpfFreq;
+                c->pScLpfMode       = sc->pScLpfMode;
+                c->pScLpfFreq       = sc->pScLpfFreq;
             }
             else
             {
@@ -225,6 +236,14 @@ namespace lsp
                 c->pScReactivity    =   vPorts[port_id++];
                 TRACE_PORT(vPorts[port_id]);
                 c->pScPreamp        =   vPorts[port_id++];
+                TRACE_PORT(vPorts[port_id]);
+                c->pScHpfMode       =   vPorts[port_id++];
+                TRACE_PORT(vPorts[port_id]);
+                c->pScHpfFreq       =   vPorts[port_id++];
+                TRACE_PORT(vPorts[port_id]);
+                c->pScLpfMode       =   vPorts[port_id++];
+                TRACE_PORT(vPorts[port_id]);
+                c->pScLpfFreq       =   vPorts[port_id++];
             }
         }
 
@@ -358,7 +377,9 @@ namespace lsp
             for (size_t i=0; i<channels; ++i)
             {
                 vChannels[i].sSC.destroy();
+                vChannels[i].sSCEq.destroy();
                 vChannels[i].sDelay.destroy();
+                vChannels[i].sCompDelay.destroy();
             }
 
             delete [] vChannels;
@@ -382,6 +403,7 @@ namespace lsp
     {
         size_t samples_per_dot  = seconds_to_samples(sr, gate_base_metadata::TIME_HISTORY_MAX / gate_base_metadata::TIME_MESH_SIZE);
         size_t channels = (nMode == GM_MONO) ? 1 : 2;
+        size_t max_delay    = millis_to_samples(fSampleRate, compressor_base_metadata::LOOKAHEAD_MAX);
 
         for (size_t i=0; i<channels; ++i)
         {
@@ -389,7 +411,9 @@ namespace lsp
             c->sBypass.init(sr);
             c->sGate.set_sample_rate(sr);
             c->sSC.set_sample_rate(sr);
-            c->sDelay.init(millis_to_samples(fSampleRate, compressor_base_metadata::LOOKAHEAD_MAX));
+            c->sSCEq.set_sample_rate(sr);
+            c->sDelay.init(max_delay);
+            c->sCompDelay.init(max_delay);
 
             for (size_t j=0; j<G_TOTAL; ++j)
                 c->sGraph[j].init(gate_base_metadata::TIME_MESH_SIZE, samples_per_dot);
@@ -401,6 +425,7 @@ namespace lsp
 
     void gate_base::update_settings()
     {
+        filter_params_t fp;
         size_t channels = (nMode == GM_MONO) ? 1 : 2;
         bool bypass     = pBypass->getValue() >= 0.5f;
 
@@ -410,6 +435,7 @@ namespace lsp
         bMSListen       = (pMSListen != NULL) ? pMSListen->getValue() >= 0.5f : false;
         fInGain         = pInGain->getValue();
         float out_gain  = pOutGain->getValue();
+        size_t latency  = 0;
 
         for (size_t i=0; i<channels; ++i)
         {
@@ -428,8 +454,31 @@ namespace lsp
             c->sSC.set_reactivity(c->pScReactivity->getValue());
             c->sSC.set_stereo_mode(((nMode == GM_MS) && (c->nScType != SCT_EXTERNAL)) ? SCSM_MIDSIDE : SCSM_STEREO);
 
+            // Setup hi-pass filter for sidechain
+            size_t hp_slope = c->pScHpfMode->getValue() * 2;
+            fp.nType        = (hp_slope > 0) ? FLT_BT_BWC_HIPASS : FLT_NONE;
+            fp.fFreq        = c->pScHpfFreq->getValue();
+            fp.fFreq2       = fp.fFreq;
+            fp.fGain        = 1.0f;
+            fp.nSlope       = hp_slope;
+            fp.fQuality     = 0.0f;
+            c->sSCEq.set_params(0, &fp);
+
+            // Setup low-pass filter for sidechain
+            size_t lp_slope = c->pScLpfMode->getValue() * 2;
+            fp.nType        = (lp_slope > 0) ? FLT_BT_BWC_LOPASS : FLT_NONE;
+            fp.fFreq        = c->pScLpfFreq->getValue();
+            fp.fFreq2       = fp.fFreq;
+            fp.fGain        = 1.0f;
+            fp.nSlope       = lp_slope;
+            fp.fQuality     = 0.0f;
+            c->sSCEq.set_params(1, &fp);
+
             // Update delay
-            c->sDelay.set_delay(millis_to_samples(fSampleRate, (c->pScLookahead != NULL) ? c->pScLookahead->getValue() : 0));
+            size_t delay    = millis_to_samples(fSampleRate, (c->pScLookahead != NULL) ? c->pScLookahead->getValue() : 0);
+            c->sDelay.set_delay(delay);
+            if (delay > latency)
+                latency         = delay;
 
             // Update Gate settings
             bool hyst       = (c->pHyst != NULL) ? (c->pHyst->getValue() >= 0.5f) : false;
@@ -467,6 +516,16 @@ namespace lsp
                 c->nSync           |= S_ALL;
             }
         }
+
+        // Tune compensation delays
+        for (size_t i=0; i<channels; ++i)
+        {
+            channel_t *c    = &vChannels[i];
+            c->sCompDelay.set_delay(latency - c->sDelay.get_delay());
+        }
+
+        // Report latency
+        set_latency(latency);
     }
 
     void gate_base::ui_activated()
@@ -551,8 +610,11 @@ namespace lsp
             {
                 channel_t *c        = &vChannels[i];
 
-                c->sDelay.process(c->vIn, c->vIn, to_process); // Add delay to original signal
-                dsp::mul3(c->vOut, c->vGain, c->vIn, to_process);
+                // Add delay to original signal and apply gain
+                c->sDelay.process(c->vOut, c->vIn, c->vGain, to_process);
+
+                // Apply latency compensation delay
+                c->sCompDelay.process(c->vOut, c->vOut, to_process);
 
                 // Process graph outputs
                 if ((i == 0) || (nMode != GM_STEREO))
@@ -659,21 +721,21 @@ namespace lsp
             // Output gate curves
             for (size_t j=0; j<2; ++j)
             {
-                if (c->pCurve[j] != NULL)
-                {
-                    mesh_t *mesh            = c->pCurve[j]->getBuffer<mesh_t>();
-                    if ((c->nSync & (S_CURVE << j)) && (mesh != NULL) && (mesh->isEmpty()))
-                    {
-                        // Copy frequency points
-                        dsp::copy(mesh->pvData[0], vCurve, gate_base_metadata::CURVE_MESH_SIZE);
-                        c->sGate.curve(mesh->pvData[1], vCurve, gate_base_metadata::CURVE_MESH_SIZE, j > 0);
-                        if (c->fMakeup != 1.0f)
-                            dsp::mul_k2(mesh->pvData[1], c->fMakeup, gate_base_metadata::CURVE_MESH_SIZE);
+                if (c->pCurve[j] == NULL)
+                    continue;
 
-                        // Mark mesh containing data
-                        mesh->data(2, gate_base_metadata::CURVE_MESH_SIZE);
-                        c->nSync &= ~(S_CURVE << j);
-                    }
+                mesh_t *mesh            = c->pCurve[j]->getBuffer<mesh_t>();
+                if ((c->nSync & (S_CURVE << j)) && (mesh != NULL) && (mesh->isEmpty()))
+                {
+                    // Copy frequency points
+                    dsp::copy(mesh->pvData[0], vCurve, gate_base_metadata::CURVE_MESH_SIZE);
+                    c->sGate.curve(mesh->pvData[1], vCurve, gate_base_metadata::CURVE_MESH_SIZE, j > 0);
+                    if (c->fMakeup != 1.0f)
+                        dsp::mul_k2(mesh->pvData[1], c->fMakeup, gate_base_metadata::CURVE_MESH_SIZE);
+
+                    // Mark mesh containing data
+                    mesh->data(2, gate_base_metadata::CURVE_MESH_SIZE);
+                    c->nSync &= ~(S_CURVE << j);
                 }
             }
 
