@@ -49,8 +49,9 @@ namespace lsp
         REQ_IDISPLAY    = 1 << 10,
         REQ_OSC_IN      = 1 << 11,
         REQ_OSC_OUT     = 1 << 12,
+        REQ_MAP_PATH    = 1 << 13,
 
-        REQ_PATH_MASK   = REQ_PATCH | REQ_STATE | REQ_WORKER | REQ_PATCH_WR,
+        REQ_PATH_MASK   = REQ_PATCH | REQ_STATE | REQ_MAP_PATH | REQ_WORKER | REQ_PATCH_WR,
         REQ_MIDI        = REQ_MIDI_IN | REQ_MIDI_OUT
     };
 
@@ -128,13 +129,14 @@ namespace lsp
         { U_SEC,        "s" },
         { U_MSEC,       "ms" },
         { U_DB,         "db" },
+        { U_MIN,        "min" },
         { U_DEG,        "degree" },
+        { U_OCTAVES,    "oct" },
+        { U_SEMITONES,  "semitone12TET" },
 
         { U_SAMPLES,    NULL,       "samples",              "%.0f"      },
-        { U_GAIN_AMP,   NULL,       "gain",                 "%f"        },
-        { U_GAIN_POW,   NULL,       "gain",                 "%f"        },
-
-        { U_SEMITONES,  NULL,       "st",                   "%.2f"      },
+        { U_GAIN_AMP,   NULL,       "gain",                 "%.8f"      },
+        { U_GAIN_POW,   NULL,       "gain",                 "%.8f"      },
 
         { U_DEG_CEL,    NULL,       "degrees Celsium",      "%.2f"      },
         { U_DEG_FAR,    NULL,       "degrees Fahrenheit",   "%.2f"      },
@@ -206,7 +208,8 @@ namespace lsp
         fprintf(out, "\tlv2:requiredFeature urid:map, ui:idleInterface ;\n");
         {
             size_t count = 1;
-            fprintf(out, "\tlv2:optionalFeature ui:parent, ui:resize, ui:noUserResize");
+//            fprintf(out, "\tlv2:optionalFeature ui:parent, ui:resize, ui:noUserResize");
+            fprintf(out, "\tlv2:optionalFeature ui:parent, ui:resize");
             LSP_LV2_EMIT_OPTION(count, requirements & REQ_INSTANCE, "lv2ext:instance-access");
             fprintf(out, " ;\n");
         }
@@ -375,6 +378,7 @@ namespace lsp
     {
         size_t result   = 0;
 
+#ifndef LSP_NO_LV2_UI
         if (m.lv2_uid != NULL)
         {
             if (m.ui_resource != NULL)
@@ -382,6 +386,7 @@ namespace lsp
             if (m.extensions & E_INLINE_DISPLAY)
                 result |= REQ_IDISPLAY;
         }
+#endif
 
         result |= scan_port_requirements(m.ports);
 
@@ -426,7 +431,7 @@ namespace lsp
         fprintf(out, "@prefix rsz:       <" LV2_RESIZE_PORT_PREFIX "> .\n");
         if (requirements & REQ_PATCH)
             fprintf(out, "@prefix patch:     <" LV2_PATCH_PREFIX "> .\n");
-        if (requirements & REQ_STATE)
+        if (requirements & (REQ_STATE | REQ_MAP_PATH))
             fprintf(out, "@prefix state:     <" LV2_STATE_PREFIX "> .\n");
         if (requirements & REQ_MIDI)
             fprintf(out, "@prefix midi:      <" LV2_MIDI_PREFIX "> .\n");
@@ -554,6 +559,7 @@ namespace lsp
             fprintf(out, "\tlv2:optionalFeature lv2:hardRTCapable");
             LSP_LV2_EMIT_OPTION(count, requirements & REQ_WORKER, "work:schedule");
             LSP_LV2_EMIT_OPTION(count, requirements & REQ_IDISPLAY, "hcid:queue_draw");
+            LSP_LV2_EMIT_OPTION(count, requirements & REQ_MAP_PATH, "state:mapPath");
             fprintf(out, " ;\n");
         }
 
@@ -652,6 +658,7 @@ namespace lsp
                     fprintf(out, "lv2:AudioPort ;\n");
                     break;
                 case R_CONTROL:
+                case R_BYPASS:
                 case R_METER:
                     fprintf(out, "lv2:ControlPort ;\n");
                     break;
@@ -660,8 +667,10 @@ namespace lsp
             }
 
             fprintf(out, "\t\tlv2:index %d ;\n", (int)port_id);
-            fprintf(out, "\t\tlv2:symbol \"%s\" ;\n", p->id);
-            fprintf(out, "\t\tlv2:name \"%s\" ;\n", p->name);
+            fprintf(out, "\t\tlv2:symbol \"%s\" ;\n", (p->role == R_BYPASS) ? "enabled" : p->id);
+            fprintf(out, "\t\tlv2:name \"%s\" ;\n", (p->role == R_BYPASS) ? "Enabled" : p->name);
+            if (p->role == R_BYPASS)
+                fprintf(out, "\t\tlv2:designation lv2:enabled ;\n");
 
             print_units(out, p->unit);
 
@@ -682,7 +691,7 @@ namespace lsp
 //                    fprintf(out, "\t\tlv2:portProperty pp:trigger ;\n");
                 fprintf(out, "\t\tlv2:minimum %d ;\n", 0);
                 fprintf(out, "\t\tlv2:maximum %d ;\n", 1);
-                fprintf(out, "\t\tlv2:default %d ;\n", int(p->start));
+                fprintf(out, "\t\tlv2:default %d ;\n", (p->role == R_BYPASS) ? (1 - int(p->start)) : int(p->start));
             }
             else if (p->unit == U_ENUM)
             {
@@ -694,35 +703,24 @@ namespace lsp
 
                 int min  = (p->flags & F_LOWER) ? p->min : 0;
                 int curr = min;
+                size_t count = list_size(p->items);
                 int max  = min + list_size(p->items) - 1;
 
-                const char **list = p->items;
-                if ((list != NULL) && (*list != NULL))
+                const port_item_t *list = p->items;
+                if (count > 1)
                 {
-                    size_t count = 0;
-                    for (const char **t = list; *t != NULL; ++t)
-                        count ++;
-
-                    if (count > 0)
+                    fprintf(out, "\t\tlv2:scalePoint\n");
+                    for ( ; list->text != NULL; ++list)
                     {
-                        fprintf(out, "\t\tlv2:scalePoint\n");
-                        while (*list != NULL)
-                        {
-                            fprintf(out, "\t\t\t[ rdfs:label \"%s\"; rdf:value %d ]", *list, curr);
-                            if (--count)
-                                fprintf(out, " ,\n");
-                            else
-                                fprintf(out, " ;\n");
-                            list ++;
-                            curr ++;
-                        }
+                        fprintf(out, "\t\t\t[ rdfs:label \"%s\"; rdf:value %d ]", list->text, curr);
+                        if (--count)
+                            fprintf(out, " ,\n");
+                        else
+                            fprintf(out, " ;\n");
+                        curr ++;
                     }
-                    else
-                        fprintf(out, "\t\tlv2:scalePoint [ rdfs:label \"%s\"; rdf:value %d ]\n", *list, curr);
-                }
-
-//                for (const char **list = p->items; *list != NULL; ++list, ++curr)
-//                    fprintf(out, "\t\tlv2:scalePoint [ rdfs:label \"%s\"; rdf:value %d ] ;\n", *list, curr);
+                } else if (count > 0)
+                    fprintf(out, "\t\tlv2:scalePoint [ rdfs:label \"%s\"; rdf:value %d ] ;\n", list->text, curr);
 
                 fprintf(out, "\t\tlv2:minimum %d ;\n", min);
                 fprintf(out, "\t\tlv2:maximum %d ;\n", max);
